@@ -256,15 +256,15 @@ void SweeperWizard::setupResultsPage()
 	QToolTip::add(regex_edit, i18n("Enter text or regular expression"));
 	connect(regex_edit, SIGNAL(textChanged(const QString&)), this, SLOT(regexChanged(const QString&)));
 	cb_regexpcase = new QCheckBox(i18n("Case sensitive"), resultspage);
-	cb_regexpgreedy = new QCheckBox(i18n("Greedy match"), resultspage);
+	//cb_regexpgreedy = new QCheckBox(i18n("Greedy match"), resultspage);
 	cb_regexpcase->setChecked(true);  //case sensitive by default
-	cb_regexpgreedy->setChecked(true);  //greedy matching by default
+	//cb_regexpgreedy->setChecked(true);  //greedy matching by default
 	b_regexpselect = new KPushButton(i18n("Select"), resultspage);
 	b_regexpunselect = new KPushButton(i18n("Unselect"), resultspage);
 	moreopt->addWidget(b_regexclr);
 	moreopt->addWidget(regex_edit);
 	moreopt->addWidget(cb_regexpcase);
-	moreopt->addWidget(cb_regexpgreedy);
+	//moreopt->addWidget(cb_regexpgreedy);
 	moreopt->addWidget(b_regexpselect);
 	moreopt->addWidget(b_regexpunselect);
 	
@@ -595,7 +595,7 @@ void SweeperWizard::enableResultsPageElements(bool f)
 	b_regexpselect->setDisabled(f || regex_empty);
 	b_regexpunselect->setDisabled(f || regex_empty);
 	cb_regexpcase->setDisabled(f);
-	cb_regexpgreedy->setDisabled(f);
+	//cb_regexpgreedy->setDisabled(f);
 }
 
 void SweeperWizard::addFileEntry(SweepScanner::FileType t, SweepFileInfo *f)
@@ -674,7 +674,7 @@ void SweeperWizard::moreClicked()
 	b_regexclr->setShown(f);
 	regex_edit->setShown(f);
 	cb_regexpcase->setShown(f);
-	cb_regexpgreedy->setShown(f);
+	//cb_regexpgreedy->setShown(f);
 	b_regexpselect->setShown(f);
 	b_regexpunselect->setShown(f);
 }
@@ -686,7 +686,8 @@ void SweeperWizard::selectRegExpClicked()
 		if (!regex_edit->text().isEmpty())
 		{
 			QRegExp rx(regex_edit->text(), cb_regexpcase->isChecked());
-			rx.setMinimal(!cb_regexpgreedy->isChecked());
+			//rx.setMinimal(!cb_regexpgreedy->isChecked());
+			rx.setMinimal(false);
 			if (rx.isValid())
 			{
 				setCursor(QCursor(Qt::WaitCursor));
@@ -708,7 +709,8 @@ void SweeperWizard::unselectRegExpClicked()
 		if (!regex_edit->text().isEmpty())
 		{
 			QRegExp rx(regex_edit->text(), cb_regexpcase->isChecked());
-			rx.setMinimal(!cb_regexpgreedy->isChecked());
+			//rx.setMinimal(!cb_regexpgreedy->isChecked());
+			rx.setMinimal(false);
 			if (rx.isValid())
 			{
 				setCursor(QCursor(Qt::WaitCursor));
